@@ -30,13 +30,14 @@ class BodhiProcessor(BaseProcessor):
             'bodhi.mashtask.complete',
             'bodhi.mashtask.sync.wait',
             'bodhi.mashtask.sync.done',
+            'bodhi.buildroot_override.tag',
         ]])
 
     def subtitle(self, msg, **config):
         if 'bodhi.update.comment' in msg['topic']:
             author = msg['msg']['comment']['author']
             karma = msg['msg']['comment']['karma']
-            title = msg['msg']['comment']['update']['title']
+            title = msg['msg']['comment']['update_title']
             if len(title) >= 35: title = title[:35] + '...'
             tmpl = self._(
                 "{author} commented on a bodhi update {title} (karma: {karma})"
@@ -51,10 +52,18 @@ class BodhiProcessor(BaseProcessor):
             )
             return tmpl.format(author=author, package=package, status=status)
         elif 'bodhi.update.request' in msg['topic']:
-            action = msg['topic'].split('.')[-1]
+            status = msg['topic'].split('.')[-1]
+            author = msg['msg']['update']['submitter']
             title = msg['msg']['update']['title']
-            tmpl = self._("{title} requested {action}")
-            return tmpl.format(action=action, title=title)
+            if status in ('unpush', 'obsolete', 'revoke'):
+                # make our status past-tense
+                status = status + (status[-1] == 'e' and 'd' or 'ed')
+                tmpl = self._("{author} {status} {title}").format(
+                        author=author, status=status, title=title)
+            else:
+                tmpl = self._("{author} submitted {title} to {status}").format(
+                        author=author, status=status, title=title)
+            return tmpl
         elif 'bodhi.mashtask.mashing' in msg['topic']:
             repo = msg['msg']['repo']
             tmpl = self._("bodhi masher is mashing {repo}")
@@ -72,5 +81,8 @@ class BodhiProcessor(BaseProcessor):
         elif 'bodhi.mashtask.sync.done' in msg['topic']:
             return self._("bodhi masher finished waiting on mirror repos " + \
                           "to sync")
+        elif 'bodhi.buildroot_override.tag' in msg['topic']:
+            tmpl = self._("{submitter} submitted a buildroot override for {build}")
+            return tmpl.format(**msg['msg']['override'])
         else:
             raise NotImplementedError
